Class: LicenseKit::RuntimeClient

Inherits:
BaseClient show all
Defined in:
lib/licensekit/generated/clients.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(base_url:, license_key: nil, headers: nil, timeout: nil, user_agent: nil, retry_options: nil, transport: nil) ⇒ RuntimeClient

Returns a new instance of RuntimeClient.



816
817
818
819
820
821
822
823
824
825
826
827
828
# File 'lib/licensekit/generated/clients.rb', line 816

def initialize(base_url:, license_key: nil, headers: nil, timeout: nil, user_agent: nil, retry_options: nil, transport: nil)
  super(
    base_url: base_url,
    auth_type: "license",
    auth_value: license_key,
    headers: headers,
    timeout: timeout,
    user_agent: user_agent,
    retry_options: retry_options,
    transport: transport
  )
  @raw = RuntimeRawClient.new(self)
end

Instance Attribute Details

#rawObject (readonly)

Returns the value of attribute raw.



814
815
816
# File 'lib/licensekit/generated/clients.rb', line 814

def raw
  @raw
end

Instance Method Details

#activate_license(request = nil, options: nil, **kwargs) ⇒ Object

Activate a license for a hardware or container binding



831
832
833
# File 'lib/licensekit/generated/clients.rb', line 831

def activate_license(request = nil, options: nil, **kwargs)
  perform_request("activateLicense", request, options: options, **kwargs)
end

#check_license(request = nil, options: nil, **kwargs) ⇒ Object

Check current entitlements without mutating validation timestamps



836
837
838
# File 'lib/licensekit/generated/clients.rb', line 836

def check_license(request = nil, options: nil, **kwargs)
  perform_request("checkLicense", request, options: options, **kwargs)
end

#checkin_floating_license(request = nil, options: nil, **kwargs) ⇒ Object

Check in a floating lease token



841
842
843
# File 'lib/licensekit/generated/clients.rb', line 841

def checkin_floating_license(request = nil, options: nil, **kwargs)
  perform_request("checkinFloatingLicense", request, options: options, **kwargs)
end

#checkout_floating_license(request = nil, options: nil, **kwargs) ⇒ Object

Check out a floating lease for a hardware or container binding



846
847
848
# File 'lib/licensekit/generated/clients.rb', line 846

def checkout_floating_license(request = nil, options: nil, **kwargs)
  perform_request("checkoutFloatingLicense", request, options: options, **kwargs)
end

#consume_license(request = nil, options: nil, **kwargs) ⇒ Object

Consume metered feature usage for an active bound license



851
852
853
# File 'lib/licensekit/generated/clients.rb', line 851

def consume_license(request = nil, options: nil, **kwargs)
  perform_request("consumeLicense", request, options: options, **kwargs)
end

#deactivate_license(request = nil, options: nil, **kwargs) ⇒ Object

Deactivate a bound license device



856
857
858
# File 'lib/licensekit/generated/clients.rb', line 856

def deactivate_license(request = nil, options: nil, **kwargs)
  perform_request("deactivateLicense", request, options: options, **kwargs)
end

#heartbeat_floating_license(request = nil, options: nil, **kwargs) ⇒ Object

Extend a floating lease before it expires



861
862
863
# File 'lib/licensekit/generated/clients.rb', line 861

def heartbeat_floating_license(request = nil, options: nil, **kwargs)
  perform_request("heartbeatFloatingLicense", request, options: options, **kwargs)
end

#issue_offline_license(request = nil, options: nil, **kwargs) ⇒ Object

Issue an encrypted offline license envelope for a bound device



866
867
868
# File 'lib/licensekit/generated/clients.rb', line 866

def issue_offline_license(request = nil, options: nil, **kwargs)
  perform_request("issueOfflineLicense", request, options: options, **kwargs)
end

#validate_license(request = nil, options: nil, **kwargs) ⇒ Object

Validate a bound license and refresh validation timestamps



871
872
873
# File 'lib/licensekit/generated/clients.rb', line 871

def validate_license(request = nil, options: nil, **kwargs)
  perform_request("validateLicense", request, options: options, **kwargs)
end