Class: LicenseKit::RuntimeRawClient
- Inherits:
-
Object
- Object
- LicenseKit::RuntimeRawClient
- Defined in:
- lib/licensekit/generated/clients.rb
Instance Method Summary collapse
-
#activate_license(request = nil, options: nil, **kwargs) ⇒ Object
Activate a license for a hardware or container binding.
-
#check_license(request = nil, options: nil, **kwargs) ⇒ Object
Check current entitlements without mutating validation timestamps.
-
#checkin_floating_license(request = nil, options: nil, **kwargs) ⇒ Object
Check in a floating lease token.
-
#checkout_floating_license(request = nil, options: nil, **kwargs) ⇒ Object
Check out a floating lease for a hardware or container binding.
-
#consume_license(request = nil, options: nil, **kwargs) ⇒ Object
Consume metered feature usage for an active bound license.
-
#deactivate_license(request = nil, options: nil, **kwargs) ⇒ Object
Deactivate a bound license device.
-
#heartbeat_floating_license(request = nil, options: nil, **kwargs) ⇒ Object
Extend a floating lease before it expires.
-
#initialize(client) ⇒ RuntimeRawClient
constructor
A new instance of RuntimeRawClient.
-
#issue_offline_license(request = nil, options: nil, **kwargs) ⇒ Object
Issue an encrypted offline license envelope for a bound device.
-
#validate_license(request = nil, options: nil, **kwargs) ⇒ Object
Validate a bound license and refresh validation timestamps.
Constructor Details
#initialize(client) ⇒ RuntimeRawClient
Returns a new instance of RuntimeRawClient.
762 763 764 |
# File 'lib/licensekit/generated/clients.rb', line 762 def initialize(client) @client = client end |
Instance Method Details
#activate_license(request = nil, options: nil, **kwargs) ⇒ Object
Activate a license for a hardware or container binding
767 768 769 |
# File 'lib/licensekit/generated/clients.rb', line 767 def activate_license(request = nil, options: nil, **kwargs) @client.send(:perform_request_raw, "activateLicense", request, options: , **kwargs) end |
#check_license(request = nil, options: nil, **kwargs) ⇒ Object
Check current entitlements without mutating validation timestamps
772 773 774 |
# File 'lib/licensekit/generated/clients.rb', line 772 def check_license(request = nil, options: nil, **kwargs) @client.send(:perform_request_raw, "checkLicense", request, options: , **kwargs) end |
#checkin_floating_license(request = nil, options: nil, **kwargs) ⇒ Object
Check in a floating lease token
777 778 779 |
# File 'lib/licensekit/generated/clients.rb', line 777 def checkin_floating_license(request = nil, options: nil, **kwargs) @client.send(:perform_request_raw, "checkinFloatingLicense", request, options: , **kwargs) end |
#checkout_floating_license(request = nil, options: nil, **kwargs) ⇒ Object
Check out a floating lease for a hardware or container binding
782 783 784 |
# File 'lib/licensekit/generated/clients.rb', line 782 def checkout_floating_license(request = nil, options: nil, **kwargs) @client.send(:perform_request_raw, "checkoutFloatingLicense", request, options: , **kwargs) end |
#consume_license(request = nil, options: nil, **kwargs) ⇒ Object
Consume metered feature usage for an active bound license
787 788 789 |
# File 'lib/licensekit/generated/clients.rb', line 787 def consume_license(request = nil, options: nil, **kwargs) @client.send(:perform_request_raw, "consumeLicense", request, options: , **kwargs) end |
#deactivate_license(request = nil, options: nil, **kwargs) ⇒ Object
Deactivate a bound license device
792 793 794 |
# File 'lib/licensekit/generated/clients.rb', line 792 def deactivate_license(request = nil, options: nil, **kwargs) @client.send(:perform_request_raw, "deactivateLicense", request, options: , **kwargs) end |
#heartbeat_floating_license(request = nil, options: nil, **kwargs) ⇒ Object
Extend a floating lease before it expires
797 798 799 |
# File 'lib/licensekit/generated/clients.rb', line 797 def heartbeat_floating_license(request = nil, options: nil, **kwargs) @client.send(:perform_request_raw, "heartbeatFloatingLicense", request, options: , **kwargs) end |
#issue_offline_license(request = nil, options: nil, **kwargs) ⇒ Object
Issue an encrypted offline license envelope for a bound device
802 803 804 |
# File 'lib/licensekit/generated/clients.rb', line 802 def issue_offline_license(request = nil, options: nil, **kwargs) @client.send(:perform_request_raw, "issueOfflineLicense", request, options: , **kwargs) end |
#validate_license(request = nil, options: nil, **kwargs) ⇒ Object
Validate a bound license and refresh validation timestamps
807 808 809 |
# File 'lib/licensekit/generated/clients.rb', line 807 def validate_license(request = nil, options: nil, **kwargs) @client.send(:perform_request_raw, "validateLicense", request, options: , **kwargs) end |